Command-line usage
==================
``bio96`` comes with a command-line tool (also called ``bio96``) that displays 
a visual representation of the plate layout described by a TOML file.  This is 
meant to help catch mistakes, which can be easy to make in complex layouts.

For more information on this command and its options, run:

.. command-output:: bio96 -h


